@@ -7,10 +7,13 @@ use Email::Valid;
 use Mail::Send;
 use File::Grep 'fgrep';
 
-our $VERSION = '1.10'; # VERSION
+our $VERSION = '1.11'; # VERSION
 
 sub init {
     my ($bot) = @_;
+    my @filter = ( ref $bot->{vars}{history}{filter} )
+        ? @{ $bot->{vars}{history}{filter} }
+        : ($bot->{vars}{history}{filter});
 
     $bot->hook(
         {
@@ -20,7 +23,10 @@ sub init {
         sub {
             my ( $bot, $in, $m ) = @_;
 
-            if ( not Email::Valid->address( $m->{email} ) ) {
+            if ( grep { lc( $in->{forum} ) eq lc($_) } @filter ) {
+                $bot->reply_to(q{I'm not allowed to return history for this channel.});
+            }
+            elsif ( not Email::Valid->address( $m->{email} ) ) {
                 $bot->reply_to('The email address you provided does not appear to be valid.');
             }
             elsif ( not -f $bot->{daemon}{stdout_file} ) {
@@ -81,7 +87,7 @@ Bot::IRC::History - Bot::IRC selected channel history dumped to email
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
@@ -90,6 +96,7 @@ version 1.10
     Bot::IRC->new(
         connect => { server => 'irc.perl.org' },
         plugins => ['History'],
+        history => { filter => ['#perl'] },
     )->run;
 
 =head1 DESCRIPTION
@@ -121,6 +128,17 @@ channel:
 
     bot history string gryphon@example.com
 
+=head2 Filtering Channels
+
+You can specify the channels to filter or disallow from history with C<vars>,
+C<history>, C<filter>, which can be either a string or arrayref.
+
+    Bot::IRC->new(
+        connect => { server => 'irc.perl.org' },
+        plugins => ['History'],
+        history => { filter => ['#perl'] },
+    )->run;
+
 =head2 SEE ALSO
 
 L<Bot::IRC>
